pype32.directories.ImageImportDescriptorEntry

Package pype32 :: Module directories :: Class ImageImportDescriptorEntry |
[hide private]
[frames] | no frames]

# Class ImageImportDescriptorEntry

source code

                     object --+
                              |
    baseclasses.BaseStructClass --+
                                  |
                                 ImageImportDescriptorEntry

ImageImportDescriptorEntry object.

Instance Methods | [hide private]
__init__(self, shouldPack=True) Class representation of a `IMAGE_IMPORT_DESCRIPTOR` structure. | source code
getType(self) Returns `consts.IMAGE_IMPORT_DESCRIPTOR_ENTRY`. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Inherited from baseclasses.BaseStructClass
__len__(self) | source code
__str__(self) str(x) | source code
dict |
getFields(self) Returns all the class attributues. | source code
sizeof(self) | source code

Static Methods | [hide private]
ImageImportDescriptorEntry |
parse(readDataInstance) Returns a new ImageImportDescriptorEntry object. | source code

Instance Variables | [hide private]
| metaData ImageImportDescriptorMetaData metaData.
| originalFirstThunk DWORD originalFirstThunk.
| timeDateStamp DWORD timeDateStamp.
| forwarderChain DWORD forwarderChain.
| name DWORD name.
| firstThunk DWORD firstThunk.
| iat ImportAddressTable iat.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
Class representation of a `IMAGE_IMPORT_DESCRIPTOR` structure. Parameters: `shouldPack` (bool) - (Optional) If set to c{True}, the object will be packed. If set to `False`, the object won't be packed. Overrides: object.__init__ See Also: Figure 5 http://msdn.microsoft.com/es-ar/magazine/bb985996%28en-us%29.aspx

### parse(readDataInstance) Static Method | source code
Returns a new ImageImportDescriptorEntry object. Parameters: `readDataInstance` (ReadData) - A ReadData object with data to be parsed as a ImageImportDescriptorEntry. Returns: ImageImportDescriptorEntry A new ImageImportDescriptorEntry object.

### getType(self) | source code
Returns `consts.IMAGE_IMPORT_DESCRIPTOR_ENTRY`. Raises: `NotImplementedError` - The method wasn't implemented in the inherited class. Overrides: baseclasses.BaseStructClass.getType